@@ -181,7 +181,7 @@ class ActionFilter(Action):
     is_string: bool = False
 
     def render_code(self, df_var_in):
-        if not self.is_string and self.value == "nan":
+        if not self.is_string and self.value is not None and self.value.lower() == "nan":
             fn = "notna" if self.op == "!=" else "isna"
             return f'{self.df_var_out} = {df_var_in}.loc[{df_var_in}["{self.col}"].{fn}()]'
 
